# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "account_manage_account_settings": "accountManageAccountSettings",
    "account_manage_apikeys": "accountManageApikeys",
    "account_manage_payment_methods": "accountManagePaymentMethods",
    "account_manage_plan": "accountManagePlan",
    "account_manage_teams": "accountManageTeams",
    "account_manage_users": "accountManageUsers",
    "account_view_activity_log": "accountViewActivityLog",
    "account_view_invoices": "accountViewInvoices",
    "additional_primaries": "additionalPrimaries",
    "autogenerate_ns_record": "autogenerateNsRecord",
    "data_manage_datafeeds": "dataManageDatafeeds",
    "data_manage_datasources": "dataManageDatasources",
    "data_push_to_datafeeds": "dataPushToDatafeeds",
    "dhcp_manage_dhcp": "dhcpManageDhcp",
    "dhcp_view_dhcp": "dhcpViewDhcp",
    "dns_manage_zones": "dnsManageZones",
    "dns_servers": "dnsServers",
    "dns_view_zones": "dnsViewZones",
    "dns_zones_allow_by_default": "dnsZonesAllowByDefault",
    "dns_zones_allows": "dnsZonesAllows",
    "dns_zones_denies": "dnsZonesDenies",
    "enable_ddi": "enableDdi",
    "ignore_ssl": "ignoreSsl",
    "ip_whitelist_strict": "ipWhitelistStrict",
    "ip_whitelists": "ipWhitelists",
    "ipam_manage_ipam": "ipamManageIpam",
    "ipam_view_ipam": "ipamViewIpam",
    "job_type": "jobType",
    "monitoring_manage_jobs": "monitoringManageJobs",
    "monitoring_manage_lists": "monitoringManageLists",
    "monitoring_view_jobs": "monitoringViewJobs",
    "notify_delay": "notifyDelay",
    "notify_failback": "notifyFailback",
    "notify_list": "notifyList",
    "notify_regional": "notifyRegional",
    "notify_repeat": "notifyRepeat",
    "nx_ttl": "nxTtl",
    "rapid_recheck": "rapidRecheck",
    "rate_limit_parallelism": "rateLimitParallelism",
    "security_manage_active_directory": "securityManageActiveDirectory",
    "security_manage_global2fa": "securityManageGlobal2fa",
    "short_answers": "shortAnswers",
    "source_id": "sourceId",
    "use_client_subnet": "useClientSubnet",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "accountManageAccountSettings": "account_manage_account_settings",
    "accountManageApikeys": "account_manage_apikeys",
    "accountManagePaymentMethods": "account_manage_payment_methods",
    "accountManagePlan": "account_manage_plan",
    "accountManageTeams": "account_manage_teams",
    "accountManageUsers": "account_manage_users",
    "accountViewActivityLog": "account_view_activity_log",
    "accountViewInvoices": "account_view_invoices",
    "additionalPrimaries": "additional_primaries",
    "autogenerateNsRecord": "autogenerate_ns_record",
    "dataManageDatafeeds": "data_manage_datafeeds",
    "dataManageDatasources": "data_manage_datasources",
    "dataPushToDatafeeds": "data_push_to_datafeeds",
    "dhcpManageDhcp": "dhcp_manage_dhcp",
    "dhcpViewDhcp": "dhcp_view_dhcp",
    "dnsManageZones": "dns_manage_zones",
    "dnsServers": "dns_servers",
    "dnsViewZones": "dns_view_zones",
    "dnsZonesAllowByDefault": "dns_zones_allow_by_default",
    "dnsZonesAllows": "dns_zones_allows",
    "dnsZonesDenies": "dns_zones_denies",
    "enableDdi": "enable_ddi",
    "ignoreSsl": "ignore_ssl",
    "ipWhitelistStrict": "ip_whitelist_strict",
    "ipWhitelists": "ip_whitelists",
    "ipamManageIpam": "ipam_manage_ipam",
    "ipamViewIpam": "ipam_view_ipam",
    "jobType": "job_type",
    "monitoringManageJobs": "monitoring_manage_jobs",
    "monitoringManageLists": "monitoring_manage_lists",
    "monitoringViewJobs": "monitoring_view_jobs",
    "notifyDelay": "notify_delay",
    "notifyFailback": "notify_failback",
    "notifyList": "notify_list",
    "notifyRegional": "notify_regional",
    "notifyRepeat": "notify_repeat",
    "nxTtl": "nx_ttl",
    "rapidRecheck": "rapid_recheck",
    "rateLimitParallelism": "rate_limit_parallelism",
    "securityManageActiveDirectory": "security_manage_active_directory",
    "securityManageGlobal2fa": "security_manage_global2fa",
    "shortAnswers": "short_answers",
    "sourceId": "source_id",
    "useClientSubnet": "use_client_subnet",
}
